@@ -1,6 +1,20 @@
 ;;; greader-espeak.el --- greader back-end for espeak. -*- lexical-binding: t; -*-
 ;; Copyright (C) 2017-2024  Free Software Foundation, Inc.
 
+;; This program is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation, either version 3 of the License, or
+;; (at your option) any later version.
+
+;; This program is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+
+;; You should have received a copy of the GNU General Public License
+;; along with this program.  If not, see
+;; <http://www.gnu.org/licenses/>.
+
 ;;; commentary:
 
 ;;; code:
@@ -53,14 +67,14 @@ LANG must be recognized by espeak or espeak-ng."
       (setq-local greader-espeak-language lang)
       (concat "-v " lang))))
 
-(defvar greader-espeak--punctuation-ring (make-ring 2))
+(defvar-local  greader-espeak--punctuation-ring (make-ring 2))
 (ring-insert greader-espeak--punctuation-ring "yes")
 (ring-insert greader-espeak--punctuation-ring "no")
-(defvar greader-espeak--ring-item (if greader-espeak-punctuation "yes"
+(defvar-local greader-espeak--ring-item (if greader-espeak-punctuation "yes"
 				    "no"))
 
 ;;;###autoload
-(defun greader-espeak (command &optional arg &rest _)
+(defun greader-espeak (command &optional arg)
   "Back-end main function for espeak.
 COMMAND must be a string suitable for `make-process'.
 ARG is applied depending on the command."
